@@ -104,6 +104,8 @@
 #'  by a scalar amount \code{delta}. These estimates can be augmented to be
 #'  consistent and efficient when two-phase sampling is performed.
 #'
+#' @export
+#'
 #' @examples
 #' set.seed(429153)
 #' n_obs <- 100
@@ -111,31 +113,31 @@
 #' A <- rnorm(n_obs, mean = 2 * W, sd = 1)
 #' Y <- rbinom(n_obs, 1, plogis(A + W + rnorm(n_obs, mean = 0, sd = 1)))
 #' C_samp <- rbinom(n_obs, 1, plogis(W + Y)) # two-phase sampling
-#'
-#' # construct a TML estimate
-#' tmle <- txshift(
-#'   W = W, A = A, Y = Y, delta = 0.5,
-#'   estimator = "onestep",
-#'   g_exp_fit_args = list(
-#'     fit_type = "hal", n_bins = 5,
-#'     grid_type = "equal_range",
-#'     lambda_seq = exp(-1:-9)
-#'   ),
-#'   Q_fit_args = list(
-#'     fit_type = "glm",
-#'     glm_formula = "Y ~ ."
-#'   )
-#' )
-#'
-#' # add a natural censoring process and construct a TML estimate
 #' C_cens <- rbinom(n_obs, 1, plogis(rowSums(W) + 0.5))
+#'
+#' # construct a TML estimate, ignoring censoring
+#' tmle <- txshift(
+#'   W = W, A = A, Y = Y, delta = 0.5,
+#'   estimator = "onestep",
+#'   g_exp_fit_args = list(
+#'     fit_type = "hal",
+#'     n_bins = 3,
+#'     lambda_seq = exp(seq(-1, -10, length = 50))
+#'   ),
+#'   Q_fit_args = list(
+#'     fit_type = "glm",
+#'     glm_formula = "Y ~ ."
+#'   )
+#' )
+#' \dontrun{
+#' # construct a TML estimate, accounting for censoring
 #' tmle <- txshift(
 #'   W = W, A = A, C_cens = C_cens, Y = Y, delta = 0.5,
 #'   estimator = "onestep",
 #'   g_exp_fit_args = list(
-#'     fit_type = "hal", n_bins = 5,
-#'     grid_type = "equal_range",
-#'     lambda_seq = exp(-1:-9)
+#'     fit_type = "hal",
+#'     n_bins = 3,
+#'     lambda_seq = exp(seq(-1, -10, length = 50))
 #'   ),
 #'   g_cens_fit_args = list(
 #'     fit_type = "glm",
@@ -147,16 +149,16 @@
 #'   )
 #' )
 #'
-#' # construct a TML estimate under two-phase sampling
+#' # construct a TML estimate under two-phase sampling, ignoring censoring
 #' ipcwtmle <- txshift(
 #'   W = W, A = A, Y = Y, delta = 0.5,
 #'   C_samp = C_samp, V = c("W", "Y"),
-#'   estimator = "onestep", max_iter = 5,
+#'   estimator = "onestep", max_iter = 3,
 #'   samp_fit_args = list(fit_type = "glm"),
 #'   g_exp_fit_args = list(
-#'     fit_type = "hal", n_bins = 5,
-#'     grid_type = "equal_range",
-#'     lambda_seq = exp(-1:-9)
+#'     fit_type = "hal",
+#'     n_bins = 3,
+#'     lambda_seq = exp(seq(-1, -10, length = 50))
 #'   ),
 #'   Q_fit_args = list(
 #'     fit_type = "glm",
@@ -165,16 +167,16 @@
 #'   eif_reg_type = "glm"
 #' )
 #'
-#' # construct a TML estimate under two-phase sampling and loss to follow-up
+#' # construct a TML estimate acconting for two-phase sampling and censoring
 #' ipcwtmle <- txshift(
 #'   W = W, A = A, C_cens = C_cens, Y = Y, delta = 0.5,
 #'   C_samp = C_samp, V = c("W", "Y"),
-#'   estimator = "onestep", max_iter = 5,
+#'   estimator = "onestep", max_iter = 3,
 #'   samp_fit_args = list(fit_type = "glm"),
 #'   g_exp_fit_args = list(
-#'     fit_type = "hal", n_bins = 5,
-#'     grid_type = "equal_range",
-#'     lambda_seq = exp(-1:-9)
+#'     fit_type = "hal",
+#'     n_bins = 3,
+#'     lambda_seq = exp(seq(-1, -10, length = 50))
 #'   ),
 #'   g_cens_fit_args = list(
 #'     fit_type = "glm",
@@ -186,7 +188,7 @@
 #'   ),
 #'   eif_reg_type = "glm"
 #' )
-#' @export
+#' }
 txshift <- function(W,
                     A,
                     C_cens = rep(1, length(A)),
@@ -203,20 +205,17 @@ txshift <- function(W,
                     ),
                     g_exp_fit_args = list(
                       fit_type = c("hal", "sl", "external"),
-                      n_bins = c(10, 25),
-                      grid_type = c("equal_range", "equal_range"),
                       lambda_seq = exp(seq(-1, -13, length = 300)),
-                      use_future = FALSE,
                       sl_learners_density = NULL
                     ),
                     g_cens_fit_args = list(
                       fit_type = c("glm", "sl", "external"),
-                      glm_formula = "C_cens ~ .",
+                      glm_formula = "C_cens ~ .^2",
                       sl_learners = NULL
                     ),
                     Q_fit_args = list(
                       fit_type = c("glm", "sl", "external"),
-                      glm_formula = "Y ~ .",
+                      glm_formula = "Y ~ .^2",
                       sl_learners = NULL
                     ),
                     eif_reg_type = c("hal", "glm"),
